@@ -2,7 +2,7 @@
 #define _INCLUDED_TIMELIMIT_CONFIG_H
 
 /*-
- * Copyright (c) 2001, 2007, 2008  Peter Pentchev
+ * Copyright (c) 2001, 2007 - 2009  Peter Pentchev
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Ringlet: config.h 2544 2008-09-03 13:24:36Z roam $ */
+ * $Ringlet: config.h 4172 2009-10-30 10:24:40Z roam $ */
 
 #define _GNU_SOURCE
 
@@ -81,4 +81,12 @@
 #endif /* __GNUC__ */
 #endif /* __unused */
 
+#ifndef __dead2
+#ifdef __GNUC__
+#define __dead2 __attribute__((noreturn))
+#else  /* __GNUC__ */
+#define __dead2
+#endif /* __GNUC__ */
+#endif /* __dead2 */
+
 #endif /* _INCLUDED */
